==> haskell-commonmark-extensions-0.2.5.5-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-extensions
version:              0.2.5.5
visibility:           public
id:                   commonmark-extensions-0.2.5.5-vXkagPV0eH90H3SWse2Xe
key:                  commonmark-extensions-0.2.5.5-vXkagPV0eH90H3SWse2Xe
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  a8828f7af77ca6f5f67a27cb65cca466
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Alerts
    Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-extensions
hs-libraries:         HScommonmark-extensions-0.2.5.5-vXkagPV0eH90H3SWse2Xe
depends:
    base-4.17.2.1 commonmark-0.2.6-3h74MjDM8mEHBoGws6vU3u
    containers-0.6.7 emojis-0.1.4.1-GsPqDvY8sjR97EGs21xpKB
    filepath-1.4.2.2 network-uri-2.6.4.2-DUv5vSA1kyG9zefYf8rGu8
    parsec-3.1.16.1 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-extensions-0.2.5.5-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-extensions
version:              0.2.5.5
visibility:           public
id:                   commonmark-extensions-0.2.5.5-ApVo4bUoJvi2deVfrQDiGJ
key:                  commonmark-extensions-0.2.5.5-ApVo4bUoJvi2deVfrQDiGJ
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  286b37c5895184a3edb1ba3f7b41afe8
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Alerts
    Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-extensions-0.2.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-extensions
hs-libraries:         HScommonmark-extensions-0.2.5.5-ApVo4bUoJvi2deVfrQDiGJ
depends:
    base-4.17.2.1 commonmark-0.2.6-1rouQV2R8Lg5f5v2aRprNz
    containers-0.6.7 emojis-0.1.4.1-DyQhqVDP88e41Ga4OUqgOp
    filepath-1.4.2.2 network-uri-2.6.4.2-KCWNlmsAWh8C1z4az19KdT
    parsec-3.1.16.1 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
